#ifndef SURFACE_INTERFACE_H
#define SURFACE_INTERFACE_H

/*!
  \file
  \brief T[tFXC^[tF[X

  \author Satofumi KAMIMURA

  $Id$

  T[tFXƂ́A`掑Ǘ

  \todo ticks ŕ`eςꍇ́AŜ̍ĕ`悪KvB
  \todo 폜pɁA`悵Ƃ ticks PvIɋL^dg݂Kv
*/

#include <SDL.h>
#include <vector>


namespace beego {
  /*!
    \brief `T[tFX̃C^[tF[X`
  */
  class SurfaceInterface {
  public:
    virtual ~SurfaceInterface() {}

    /*!
      \brief T[tFX̎`

      \param pos [i] `ʒu
      \param area [i] `ItZbgAѕ`TCY

      `ʒun_ƂāA`ItZbg`TCY`悷
    */
    virtual void draw(std::vector<SDL_Rect>& update_rects,
                      const SDL_Rect* pos, const SDL_Rect* area) = 0;
    virtual size_t getWidth(void) = 0;
    virtual size_t getHeight(void) = 0;
    virtual void forceSetChanged(void) = 0;
    virtual bool isChanged(size_t ticks) = 0;
    virtual bool isTransparent(void) = 0;
  };
};

#endif /* !SURFACE_INTERFACE_H */
